# Default command-line parameters; the below line must be first non-comment line of the script
param([string]$HostEsxi = "",
	[string]$UserName = "",
	[string]$UserPassword = "",
	[string]$FieldName = "",
	[string]$ClassName = ""
);

Import-Module CimCmdlets

# Script name (without path)
$SelfName = $MyInvocation.MyCommand.Name
# Sanity checks
if (($HostEsxi -eq "") -or ($UserName -eq "") -or ($UserPassword -eq "") -or ($ClassName -eq "")) {
	Write-host "$($SelfName) parameters expected, i.e. `n    $($SelfName) -HostEsxi ipaddr -UserName root -UserPassword password -ClassName classname [-FieldName fieldname]"
	Exit 1
}
# Encrypt plain password passed
$HostPassword = $UserPassword | ConvertTo-SecureString -AsPlaintext -Force

# Authenticate and create session for ESXi host
$Credentials = New-object -typename System.Management.Automation.PSCredential -argumentlist $UserName, $HostPassword
$CIOpt = New-CimSessionOption -SkipCACheck -SkipCNCheck -SkipRevocationCheck -Encoding Utf8 -UseSsl
$Session = New-CimSession -Authentication Basic -Credential $Credentials -ComputerName $HostEsxi -port 443 -SessionOption $CIOpt
# Get instance of specified class name, print all fields
$RC = Get-CimInstance -CimSession $Session -ClassName $ClassName
if ($FieldName -ne "") {
	$RC.$FieldName
} else {
	$RC
}
Exit 0

